Documentation — Schematics 0.9.2 documentation

### Navigation

- index
- modules |
- Schematics 0.9.2 documentation »

# Documentation

## Getting Started

New Schematics users should start with the Quickstart Guide. That is the fastest way to get a look at what Schematics does.

## Usage

Schematics exists to make a few concepts easy to glue together. The types allow us to describe units of data, models let us put them together into structures with fields. We can then import data, check if it looks correct, and easily serialize the results into any format we need.

- Types
  - Coercion
  - Conversion
  - Validation
- Models
  - Simple Model
  - Model Configuration
- Exporting
  - Terminology
  - Converting Data
  - Compound Types
  - Customizing Output
- Importing
  - Compound Types
- Validation
  - Validation Errors
  - Extending Validation

## API Reference

The User’s Guide provides the high-level concepts, but the code itself provides the most accurate reference.

- Models
- Validation
- Transforms
- Types
- Contrib

### Navigation

- index
- modules |
- Schematics 0.9.2 documentation »